@@ -57,14 +57,24 @@ struct _EBookBackendMAPIContactsPrivate
 };
 
 static gboolean
-build_restriction_emails_contains (struct mapi_SRestriction *res, const gchar *query)
+build_restriction_emails_contains (EMapiConnection *conn,
+				   mapi_id_t fid,
+				   TALLOC_CTX *mem_ctx,
+				   struct mapi_SRestriction **restrictions,
+				   gpointer user_data,
+				   GCancellable *cancellable,
+				   GError **perror)
 {
-	gchar *email=NULL, *tmp, *tmp1;
+	struct mapi_SRestriction *restriction;
+	const gchar *query = user_data;
+	gchar *email = NULL, *to_free, *tmp, *tmp1;
+
+	g_return_val_if_fail (query != NULL, FALSE);
 
 	/* This currently supports "email foo@bar.soo" */
-	tmp = strdup (query);
+	to_free = strdup (query);
 
-	tmp = strstr (tmp, "email");
+	tmp = strstr (to_free, "email");
 	if (tmp ) {
 		tmp = strchr (tmp, '\"');
 		if (tmp && ++tmp) {
@@ -80,21 +90,35 @@ build_restriction_emails_contains (struct mapi_SRestriction *res, const gchar *q
 		}
 	}
 
-	if (email==NULL || !strchr (email, '@'))
+	if (email == NULL || !strchr (email, '@')) {
+		g_free (to_free);
 		return FALSE;
+	}
 
-	res->rt = RES_PROPERTY;
-	res->res.resProperty.relop = RES_PROPERTY;
-	res->res.resProperty.ulPropTag = PROP_TAG(PT_UNICODE, 0x801f); /* EMAIL */
-	res->res.resProperty.lpProp.ulPropTag = PROP_TAG(PT_UNICODE, 0x801f); /* EMAIL*/
-	res->res.resProperty.lpProp.value.lpszA = email;
+	if (!restrictions) {
+		g_free (to_free);
+		return TRUE;
+	}
+
+	restriction = talloc_zero (mem_ctx, struct mapi_SRestriction);
+	g_return_val_if_fail (restriction != NULL, FALSE);
+
+	restriction->rt = RES_PROPERTY;
+	restriction->res.resProperty.relop = RES_PROPERTY;
+	restriction->res.resProperty.ulPropTag = PROP_TAG(PT_UNICODE, 0x801f); /* EMAIL */
+	restriction->res.resProperty.lpProp.ulPropTag = PROP_TAG(PT_UNICODE, 0x801f); /* EMAIL*/
+	restriction->res.resProperty.lpProp.value.lpszA = talloc_strdup (mem_ctx, email);
+
+	*restrictions = restriction;
+
+	g_free (to_free);
 
 	return TRUE;
 }
 
 #if 0
 static gboolean
-build_multiple_restriction_emails_contains (ExchangeMapiConnection *conn, mapi_id_t fid, struct mapi_SRestriction *res,
+build_multiple_restriction_emails_contains (EMapiConnection *conn, mapi_id_t fid, struct mapi_SRestriction *res,
 					    struct mapi_SRestriction_or *or_res,
 					    const gchar *query, gchar **to_free)
 {
@@ -147,17 +171,17 @@ build_multiple_restriction_emails_contains (ExchangeMapiConnection *conn, mapi_i
 
 	or_res[3].rt = RES_CONTENT;
 	or_res[3].res.resContent.fuzzy = FL_FULLSTRING | FL_IGNORECASE;
-	or_res[3].res.resContent.ulPropTag = exchange_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail1OriginalDisplayName, NULL);
+	or_res[3].res.resContent.ulPropTag = e_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail1OriginalDisplayName, NULL, NULL);
 	or_res[3].res.resContent.lpProp.value.lpszA = email;
 
 	or_res[4].rt = RES_CONTENT;
 	or_res[4].res.resContent.fuzzy = FL_FULLSTRING | FL_IGNORECASE;
-	or_res[4].res.resContent.ulPropTag = exchange_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail2OriginalDisplayName, NULL);
+	or_res[4].res.resContent.ulPropTag = e_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail2OriginalDisplayName, NULL, NULL);
 	or_res[4].res.resContent.lpProp.value.lpszA = email;
 
 	or_res[5].rt = RES_CONTENT;
 	or_res[5].res.resContent.fuzzy = FL_FULLSTRING | FL_IGNORECASE;
-	or_res[5].res.resContent.ulPropTag = exchange_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail3OriginalDisplayName, NULL);
+	or_res[5].res.resContent.ulPropTag = e_mapi_connection_resolve_named_prop (conn, fid, PidLidEmail3OriginalDisplayName, NULL, NULL);
 	or_res[5].res.resContent.lpProp.value.lpszA = email;
 
 	res = g_new0 (struct mapi_SRestriction, 1);
@@ -229,7 +253,14 @@ typedef struct {
 } MapiCreateitemData;
 
 static gboolean
-mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *mem_ctx, struct SPropValue **values, uint32_t *n_values, gpointer data)
+mapi_book_write_props (EMapiConnection *conn,
+		       mapi_id_t fid,
+		       TALLOC_CTX *mem_ctx,
+		       struct SPropValue **values,
+		       uint32_t *n_values,
+		       gpointer data,
+		       GCancellable *cancellable,
+		       GError **perror)
 {
 	/* Do not make this array static, below function modifies it.
 	   The array is used to just ensure named ids are known later. */
@@ -255,12 +286,12 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 	MapiCreateitemData *mcd = data;
 
 	#define set_str_value(hex, val) G_STMT_START { \
-		if (!exchange_mapi_utils_add_spropvalue (mem_ctx, values, n_values, hex, val ? val : "")) \
+		if (!e_mapi_utils_add_spropvalue (mem_ctx, values, n_values, hex, val ? val : "")) \
 			return FALSE;	\
 		} G_STMT_END
 
 	#define set_str_named_value(named_id, val) G_STMT_START { \
-		if (!exchange_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values, named_id, val ? val : "")) \
+		if (!e_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values, named_id, val ? val : "", cancellable, perror)) \
 			return FALSE;	\
 		} G_STMT_END
 
@@ -282,7 +313,7 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 	g_return_val_if_fail (values != NULL, FALSE);
 	g_return_val_if_fail (n_values != NULL, FALSE);
 
-	if (!exchange_mapi_connection_resolve_named_props (conn, fid, nids, G_N_ELEMENTS (nids), NULL))
+	if (!e_mapi_connection_resolve_named_props (conn, fid, nids, G_N_ELEMENTS (nids), cancellable, perror))
 		return FALSE;
 
 	if (GPOINTER_TO_INT (e_contact_get (mcd->contact, E_CONTACT_IS_LIST))) {
@@ -331,7 +362,7 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 
 		set_str_value (PR_MESSAGE_CLASS, IPM_DISTLIST);
 		u32 = 0xFFFFFFFF;
-		if (!exchange_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values, PidLidFileUnderId, &u32))
+		if (!e_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values, PidLidFileUnderId, &u32, cancellable, perror))
 			return FALSE;
 		set_str_named_con_value (PidLidFileUnder, E_CONTACT_FILE_AS);
 		set_str_named_con_value (PidLidDistributionListName, E_CONTACT_FILE_AS);
@@ -374,15 +405,15 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 						members->lpbin[members->cValues].cb = string_to_bin (mem_ctx, g_hash_table_lookup (member_values, raw), &members->lpbin[members->cValues].lpb);
 						members->cValues++;
 					} else {
-						exchange_mapi_util_recip_entryid_generate_smtp (mem_ctx, &members->lpbin[members->cValues], nm ? nm : "", eml);
+						e_mapi_util_recip_entryid_generate_smtp (mem_ctx, &members->lpbin[members->cValues], nm ? nm : "", eml);
 						members->cValues++;
 					}
 
-					exchange_mapi_util_recip_entryid_generate_smtp (mem_ctx, &oneoff_members->lpbin[oneoff_members->cValues], nm ? nm : "", eml);
+					e_mapi_util_recip_entryid_generate_smtp (mem_ctx, &oneoff_members->lpbin[oneoff_members->cValues], nm ? nm : "", eml);
 					oneoff_members->cValues++;
 
 					list_size += MAX (oneoff_members->lpbin[oneoff_members->cValues - 1].cb, members->lpbin[members->cValues - 1].cb);
-					crc32 = exchange_mapi_utils_push_crc32 (crc32, members->lpbin[members->cValues - 1].lpb, members->lpbin[members->cValues - 1].cb);
+					crc32 = e_mapi_utils_push_crc32 (crc32, members->lpbin[members->cValues - 1].lpb, members->lpbin[members->cValues - 1].cb);
 				}
 			}
 
@@ -397,16 +428,16 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 		g_list_foreach (local, (GFunc)e_vcard_attribute_free, NULL);
 		g_list_free (local);
 
-		if (!exchange_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
-			PidLidDistributionListOneOffMembers, oneoff_members))
+		if (!e_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
+			PidLidDistributionListOneOffMembers, oneoff_members, cancellable, perror))
 			return FALSE;
 
-		if (!exchange_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
-			PidLidDistributionListMembers, members))
+		if (!e_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
+			PidLidDistributionListMembers, members, cancellable, perror))
 			return FALSE;
 
-		if (!exchange_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
-			PidLidDistributionListChecksum, &crc32))
+		if (!e_mapi_utils_add_spropvalue_namedid (conn, fid, mem_ctx, values, n_values,
+			PidLidDistributionListChecksum, &crc32, cancellable, perror))
 			return FALSE;
 
 		/* list_size shouldn't exceed 15000 bytes, is so, use a stream instead of those properties above, but for now... */
@@ -465,9 +496,9 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 		tmtime.tm_mon = date->month - 1;
 		tmtime.tm_year = date->year - 1900;
 
-		exchange_mapi_util_time_t_to_filetime (mktime (&tmtime) + (24 * 60 * 60), &t);
+		e_mapi_util_time_t_to_filetime (mktime (&tmtime) + (24 * 60 * 60), &t);
 
-		if (!exchange_mapi_utils_add_spropvalue (mem_ctx, values, n_values, PR_BIRTHDAY, &t))
+		if (!e_mapi_utils_add_spropvalue (mem_ctx, values, n_values, PR_BIRTHDAY, &t))
 			return FALSE;
 	}
 
@@ -480,9 +511,9 @@ mapi_book_write_props (ExchangeMapiConnection *conn, mapi_id_t fid, TALLOC_CTX *
 		tmtime.tm_mon = date->month - 1;
 		tmtime.tm_year = date->year - 1900;
 
-		exchange_mapi_util_time_t_to_filetime (mktime (&tmtime) + (24 * 60 * 60), &t);
+		e_mapi_util_time_t_to_filetime (mktime (&tmtime) + (24 * 60 * 60), &t);
 
-		if (!exchange_mapi_utils_add_spropvalue (mem_ctx, values, n_values, PR_WEDDING_ANNIVERSARY, &t))
+		if (!e_mapi_utils_add_spropvalue (mem_ctx, values, n_values, PR_WEDDING_ANNIVERSARY, &t))
 			return FALSE;
 	}
 
@@ -524,7 +555,10 @@ struct FetchContactItemData
 };
 
 static gboolean
-fetch_contact_item_cb (FetchItemsCallbackData *item_data, gpointer data)
+fetch_contact_item_cb (FetchItemsCallbackData *item_data,
+		       gpointer data,
+		       GCancellable *cancellable,
+		       GError **perror)
 {
 	struct FetchContactItemData *fcid = data;
 
@@ -534,7 +568,7 @@ fetch_contact_item_cb (FetchItemsCallbackData *item_data, gpointer data)
 	fcid->contact = mapi_book_utils_contact_from_props (item_data->conn, item_data->fid, e_book_backend_mapi_get_book_uri (fcid->ebma), item_data->properties, NULL);
 
 	if (fcid->contact) {
-		gchar *suid = exchange_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
+		gchar *suid = e_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
 
 		/* UID of the contact is nothing but the concatenated string of hex id of folder and the message.*/
 		e_contact_set (fcid->contact, E_CONTACT_UID, suid);
@@ -557,7 +591,10 @@ struct CreateContactListData
 };
 
 static gboolean
-create_contact_list_cb (FetchItemsCallbackData *item_data, gpointer data)
+create_contact_list_cb (FetchItemsCallbackData *item_data,
+			gpointer data,
+			GCancellable *cancellable,
+			GError **perror)
 {
 	struct CreateContactListData *ccld = data;
 	EContact *contact;
@@ -568,7 +605,7 @@ create_contact_list_cb (FetchItemsCallbackData *item_data, gpointer data)
 
 	contact = mapi_book_utils_contact_from_props (item_data->conn, item_data->fid, e_book_backend_mapi_get_book_uri (ccld->ebma), item_data->properties, NULL);
 	if (contact) {
-		gchar *suid = exchange_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
+		gchar *suid = e_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
 
 		e_contact_set (contact, E_CONTACT_UID, suid);
 
@@ -591,7 +628,10 @@ struct FetchContactsData
 };
 
 static gboolean
-fetch_contacts_cb (FetchItemsCallbackData *item_data, gpointer data)
+fetch_contacts_cb (FetchItemsCallbackData *item_data,
+		   gpointer data,
+		   GCancellable *cancellable,
+		   GError **perror)
 {
 	struct FetchContactsData *fcd = data;
 	EContact *contact;
@@ -606,7 +646,7 @@ fetch_contacts_cb (FetchItemsCallbackData *item_data, gpointer data)
 		gchar *suid;
 		struct timeval *last_modification = NULL, tv = { 0 };
 
-		suid = exchange_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
+		suid = e_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
 		e_contact_set (contact, E_CONTACT_UID, suid);
 		g_free (suid);
 
@@ -626,23 +666,26 @@ fetch_contacts_cb (FetchItemsCallbackData *item_data, gpointer data)
 
 struct FetchContactsUidsData
 {
-	GCancellable *cancelled;
+	GCancellable *cancellable;
 	GHashTable *uids;
 };
 
 static gboolean
-fetch_contacts_uids_cb (FetchItemsCallbackData *item_data, gpointer data)
+fetch_contacts_uids_cb (FetchItemsCallbackData *item_data,
+			gpointer data,
+			GCancellable *cancellable,
+			GError **perror)
 {
 	struct FetchContactsUidsData *fcud = data;
 	gchar *suid;
 
 	g_return_val_if_fail (data != NULL, FALSE);
 
-	suid = exchange_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
+	suid = e_mapi_util_mapi_ids_to_uid (item_data->fid, item_data->mid);
 	if (suid)
 		g_hash_table_insert (fcud->uids, suid, GINT_TO_POINTER (1));
 
-	return !g_cancellable_is_cancelled (fcud->cancelled);
+	return !g_cancellable_is_cancelled (fcud->cancellable);
 }
 
 static void
@@ -661,7 +704,7 @@ ebbm_contacts_open (EBookBackendMAPI *ebma, GCancellable *cancellable, gboolean
 	priv->fid = 0;
 	priv->is_public_folder = g_strcmp0 (e_source_get_property (source, "public"), "yes") == 0;
 
-	exchange_mapi_util_mapi_id_from_string (e_source_get_property (source, "folder-id"), &priv->fid);
+	e_mapi_util_mapi_id_from_string (e_source_get_property (source, "folder-id"), &priv->fid);
 
 	/* Chain up to parent's op_load_source() method. */
 	if (E_BOOK_BACKEND_MAPI_CLASS (e_book_backend_mapi_contacts_parent_class)->op_open)
@@ -699,7 +742,7 @@ ebbm_contacts_remove (EBookBackendMAPI *ebma, GCancellable *cancellable, GError
 	}
 
 	if (!priv->is_public_folder) {
-		ExchangeMapiConnection *conn;
+		EMapiConnection *conn;
 
 		e_book_backend_mapi_lock_connection (ebma);
 
@@ -707,7 +750,7 @@ ebbm_contacts_remove (EBookBackendMAPI *ebma, GCancellable *cancellable, GError
 		if (!conn) {
 			g_propagate_error (error, EDB_ERROR (OFFLINE_UNAVAILABLE));
 		} else {
-			exchange_mapi_connection_remove_folder (conn, priv->fid, 0, &mapi_error);
+			e_mapi_connection_remove_folder (conn, priv->fid, 0, cancellable, &mapi_error);
 
 			if (mapi_error) {
 				mapi_error_to_edb_error (error, mapi_error, E_DATA_BOOK_STATUS_OTHER_ERROR, _("Failed to remove public folder"));
@@ -724,7 +767,7 @@ ebbm_contacts_create_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	MapiCreateitemData mcd;
 	GError *mapi_error = NULL;
 	mapi_id_t mid;
@@ -766,9 +809,9 @@ ebbm_contacts_create_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 	e_book_backend_mapi_get_db (ebma, &mcd.db);
 	mcd.contact = contact;
 
-	mid = exchange_mapi_connection_create_item (conn, olFolderContacts, priv->fid,
+	mid = e_mapi_connection_create_item (conn, olFolderContacts, priv->fid,
 		mapi_book_write_props, &mcd,
-		NULL, NULL, NULL, MAPI_OPTIONS_DONT_SUBMIT | (priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0), &mapi_error);
+		NULL, NULL, NULL, MAPI_OPTIONS_DONT_SUBMIT | (priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0), cancellable, &mapi_error);
 
 	e_book_backend_mapi_unlock_connection (ebma);
 
@@ -782,7 +825,7 @@ ebbm_contacts_create_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 		return;
 	}
 
-	id = exchange_mapi_util_mapi_ids_to_uid (priv->fid, mid);
+	id = e_mapi_util_mapi_ids_to_uid (priv->fid, mid);
 
 	/* UID of the contact is nothing but the concatenated string of hex id of folder and the message.*/
 	e_contact_set (contact, E_CONTACT_UID, id);
@@ -798,7 +841,7 @@ ebbm_contacts_remove_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	GError *mapi_error = NULL;
 	GSList *to_remove;
 	const GSList *l;
@@ -829,7 +872,7 @@ ebbm_contacts_remove_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 		const gchar *uid = l->data;
 		struct id_list *idl = g_new0 (struct id_list, 1);
 
-		exchange_mapi_util_mapi_ids_from_uid (uid, &fid, &mid);
+		e_mapi_util_mapi_ids_from_uid (uid, &fid, &mid);
 
 		idl->id = mid;
 		to_remove = g_slist_prepend (to_remove, idl);
@@ -837,7 +880,7 @@ ebbm_contacts_remove_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 		*removed_ids = g_slist_prepend (*removed_ids, g_strdup (uid));
 	}
 
-	exchange_mapi_connection_remove_items (conn, olFolderContacts, priv->fid, priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0, to_remove, &mapi_error);
+	e_mapi_connection_remove_items (conn, olFolderContacts, priv->fid, priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0, to_remove, cancellable, &mapi_error);
 
 	e_book_backend_mapi_unlock_connection (ebma);
 
@@ -860,7 +903,7 @@ ebbm_contacts_modify_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	MapiCreateitemData mcd;
 	EContact *contact;
 	GError *mapi_error = NULL;
@@ -901,10 +944,10 @@ ebbm_contacts_modify_contacts (EBookBackendMAPI *ebma, GCancellable *cancellable
 	e_book_backend_mapi_get_db (ebma, &mcd.db);
 	mcd.contact = contact;
 
-	exchange_mapi_util_mapi_ids_from_uid (e_contact_get_const (contact, E_CONTACT_UID), &fid, &mid);
+	e_mapi_util_mapi_ids_from_uid (e_contact_get_const (contact, E_CONTACT_UID), &fid, &mid);
 
-	if (!exchange_mapi_connection_modify_item (conn, olFolderContacts, priv->fid, mid,
-		mapi_book_write_props, &mcd, NULL, NULL, NULL, priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0, &mapi_error)) {
+	if (!e_mapi_connection_modify_item (conn, olFolderContacts, priv->fid, mid,
+		mapi_book_write_props, &mcd, NULL, NULL, NULL, priv->is_public_folder ? MAPI_OPTIONS_USE_PFSTORE : 0, cancellable, &mapi_error)) {
 
 		mapi_error_to_edb_error (error, mapi_error, E_DATA_BOOK_STATUS_OTHER_ERROR, _("Failed to modify item on a server"));
 		if (mapi_error)
@@ -923,7 +966,7 @@ ebbm_contacts_get_contact (EBookBackendMAPI *ebma, GCancellable *cancellable, co
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	mapi_id_t fid, mid;
 	guint32 options;
 	struct FetchContactItemData fcid = { 0 };
@@ -967,12 +1010,12 @@ ebbm_contacts_get_contact (EBookBackendMAPI *ebma, GCancellable *cancellable, co
 
 	fcid.ebma = ebma;
 	fcid.contact = NULL;
-	exchange_mapi_util_mapi_ids_from_uid (id, &fid, &mid);
+	e_mapi_util_mapi_ids_from_uid (id, &fid, &mid);
 
-	exchange_mapi_connection_fetch_item (conn, priv->fid, mid,
+	e_mapi_connection_fetch_item (conn, priv->fid, mid,
 		priv->is_public_folder ? NULL : mapi_book_utils_get_prop_list, GET_ALL_KNOWN_IDS,
 		fetch_contact_item_cb, &fcid,
-		options, &mapi_error);
+		options, cancellable, &mapi_error);
 
 	if (fcid.contact) {
 		*vcard =  e_vcard_to_string (E_VCARD (fcid.contact), EVC_FORMAT_VCARD_30);
@@ -996,11 +1039,10 @@ ebbm_contacts_get_contact_list (EBookBackendMAPI *ebma, GCancellable *cancellabl
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	guint32 options;
 	struct CreateContactListData ccld = { 0 };
 	GError *mapi_error = NULL;
-	struct mapi_SRestriction res;
 	gboolean get_all;
 
 	e_return_data_book_error_if_fail (ebma != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
@@ -1044,16 +1086,16 @@ ebbm_contacts_get_contact_list (EBookBackendMAPI *ebma, GCancellable *cancellabl
 	ccld.vCards = vCards;
 
 	get_all = g_ascii_strcasecmp (query, "(contains \"x-evolution-any-field\" \"\")") == 0;
-	if (!get_all && !build_restriction_emails_contains (&res, query)) {
+	if (!get_all && !build_restriction_emails_contains (NULL, 0, NULL, NULL, (gpointer) query, NULL, NULL)) {
 		e_book_backend_mapi_unlock_connection (ebma);
 		/* g_propagate_error (error, EDB_ERROR (OTHER_ERROR)); */
 
 		return;
 	}
 
-	if (!exchange_mapi_connection_fetch_items (conn, priv->fid, get_all ? NULL : &res, NULL,
+	if (!e_mapi_connection_fetch_items (conn, priv->fid, get_all ? NULL : build_restriction_emails_contains, (gpointer) query, NULL,
 		priv->is_public_folder ? NULL : mapi_book_utils_get_prop_list, GET_ALL_KNOWN_IDS,
-		create_contact_list_cb, &ccld, options, &mapi_error)) {
+		create_contact_list_cb, &ccld, options, cancellable, &mapi_error)) {
 		mapi_error_to_edb_error (error, mapi_error, E_DATA_BOOK_STATUS_OTHER_ERROR, _("Failed to fetch items from a server"));
 		if (mapi_error)
 			g_error_free (mapi_error);
@@ -1081,11 +1123,11 @@ ebbm_contacts_get_status_message (EBookBackendMAPI *ebma, gint index, gint total
 }
 
 static void
-ebbm_contacts_fetch_contacts (EBookBackendMAPI *ebma, struct mapi_SRestriction *restriction, EDataBookView *book_view, gpointer notify_contact_data, GError **error)
+ebbm_contacts_fetch_contacts (EBookBackendMAPI *ebma, BuildRestrictionsCB build_rs_cb, gpointer build_rs_cb_data, EDataBookView *book_view, gpointer notify_contact_data, GError **error)
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	guint32 options;
 	struct FetchContactsData fcd = { 0 };
 	GError *mapi_error = NULL;
@@ -1117,9 +1159,9 @@ ebbm_contacts_fetch_contacts (EBookBackendMAPI *ebma, struct mapi_SRestriction *
 	if (priv->is_public_folder)
 		options |= MAPI_OPTIONS_USE_PFSTORE;
 
-	if (!exchange_mapi_connection_fetch_items (conn, priv->fid, restriction, NULL,
+	if (!e_mapi_connection_fetch_items (conn, priv->fid, build_rs_cb, build_rs_cb_data, NULL,
 		mapi_book_utils_get_prop_list, GET_ALL_KNOWN_IDS,
-		fetch_contacts_cb, &fcd, options, &mapi_error)) {
+		fetch_contacts_cb, &fcd, options, NULL, &mapi_error)) {
 		mapi_error_to_edb_error (error, mapi_error, E_DATA_BOOK_STATUS_OTHER_ERROR, _("Failed to fetch items from a server"));
 
 		if (mapi_error)
@@ -1130,18 +1172,18 @@ ebbm_contacts_fetch_contacts (EBookBackendMAPI *ebma, struct mapi_SRestriction *
 }
 
 static void
-ebbm_contacts_fetch_known_uids (EBookBackendMAPI *ebma, GCancellable *cancelled, GHashTable *uids, GError **error)
+ebbm_contacts_fetch_known_uids (EBookBackendMAPI *ebma, GCancellable *cancellable, GHashTable *uids, GError **error)
 {
 	EBookBackendMAPIContacts *ebmac;
 	EBookBackendMAPIContactsPrivate *priv;
-	ExchangeMapiConnection *conn;
+	EMapiConnection *conn;
 	GError *mapi_error = NULL;
 	struct FetchContactsUidsData fcud = { 0 };
 	guint32 options;
 
 	e_return_data_book_error_if_fail (ebma != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
 	e_return_data_book_error_if_fail (E_IS_BOOK_BACKEND_MAPI_CONTACTS (ebma), E_DATA_BOOK_STATUS_INVALID_ARG);
-	e_return_data_book_error_if_fail (cancelled != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
+	e_return_data_book_error_if_fail (cancellable != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
 	e_return_data_book_error_if_fail (uids != NULL, E_DATA_BOOK_STATUS_INVALID_ARG);
 
 	ebmac = E_BOOK_BACKEND_MAPI_CONTACTS (ebma);
@@ -1163,12 +1205,12 @@ ebbm_contacts_fetch_known_uids (EBookBackendMAPI *ebma, GCancellable *cancelled,
 	if (priv->is_public_folder)
 		options |= MAPI_OPTIONS_USE_PFSTORE;
 
-	fcud.cancelled = cancelled;
+	fcud.cancellable = cancellable;
 	fcud.uids = uids;
 
-	exchange_mapi_connection_fetch_items (conn, priv->fid, NULL, NULL,
+	e_mapi_connection_fetch_items (conn, priv->fid, NULL, NULL, NULL,
 		mapi_book_utils_get_prop_list, GET_UIDS_ONLY,
-		fetch_contacts_uids_cb, &fcud, options, &mapi_error);
+		fetch_contacts_uids_cb, &fcud, options, cancellable, &mapi_error);
 
 	if (mapi_error) {
 		mapi_error_to_edb_error (error, mapi_error, E_DATA_BOOK_STATUS_OTHER_ERROR, _("Failed to fetch items from a server"));
